@@ -110,7 +110,8 @@ sub register_stock_icons {
       my $filename = "gtk-logo-rgb.gif";
       if ($filename) {
           eval {
-             $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file ($filename);
+             $pixbuf = Gtk2::Gdk::Pixbuf->new_from_file (
+		     main::demo_find_file ($filename));
 
 ##          GtkIconSet *icon_set;
 ##          GdkPixbuf *transparent;
@@ -282,3 +283,20 @@ sub do {
 
 
 1;
+__END__
+Copyright (C) 2003 by the gtk2-perl team (see the file AUTHORS for the
+full list)
+
+This library is free software; you can redistribute it and/or modify it under
+the terms of the GNU Library General Public License as published by the Free
+Software Foundation; either version 2.1 of the License, or (at your option) any
+later version.
+
+This library is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE.  See the GNU Library General Public License for more
+details.
+
+You should have received a copy of the GNU Library General Public License along
+with this library; if not, write to the Free Software Foundation, Inc., 59
+Temple Place - Suite 330, Boston, MA  02111-1307  USA.
